# -*- coding: utf-8 -*-
# from plone.app.upgrade.utils import loadMigrationProfile
#
#
# def reload_gs_profile(context):
#     loadMigrationProfile(context, "profile-library.core:default")


def geolocation_behavior(context):
    context.runAllImportStepsFromProfile("profile-collective.faceted.map:default")
    context.runImportStepFromProfile("profile-library.core:default", "typeinfo")



# -*- coding: utf-8 -*-

from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


class ColorsVocabularyFactory:
    def __call__(self, context):
        provinces = [
            ("couleur", "Couleur"),
            ("noiretbanc", "Noir & Blanc"),
        ]
        terms = [
            SimpleTerm(value=pair[0], token=pair[0], title=pair[1])
            for pair in provinces
        ]
        return SimpleVocabulary(terms)


colorsvocabulary = ColorsVocabularyFactory()


class EventsdateVocabularyFactory:
    def __call__(self, context):
        provinces = [
            ("Naissance", "Naissance"),
            ("Mariage", "Mariage"),
            ("Deces", "Décès"),
        ]
        terms = [
            SimpleTerm(value=pair[0], token=pair[0], title=pair[1])
            for pair in provinces
        ]
        return SimpleVocabulary(terms)


eventsdatevocabulary = EventsdateVocabularyFactory()


class ProvincesVocabularyFactory:
    def __call__(self, context):
        provinces = [
            ("brabantwallon", "Brabant wallon"),
            ("hainaut", "Hainaut"),
            ("liege", "Liège"),
            ("luxembourg", "Luxembourg"),
            ("namur", "Namur"),
        ]
        terms = [
            SimpleTerm(value=pair[0], token=pair[0], title=pair[1])
            for pair in provinces
        ]
        return SimpleVocabulary(terms)


provincesvocabulary = ProvincesVocabularyFactory()


class MunicipalEntitiesVocabularyFactory:
    def __call__(self, context):
        municipal_entities = [
            ("aiseaupresles", "Aiseau-Presles"),
            ("amay", "Amay"),
            ("ambleve", "Amblève"),
            ("andenne", "Andenne"),
            ("anderlues", "Anderlues"),
            ("anhee", "Anhée"),
            ("ans", "Ans"),
            ("anthisnes", "Anthisnes"),
            ("antoing", "Antoing"),
            ("arlon", "Arlon"),
            ("assesse", "Assesse"),
            ("ath", "Ath"),
            ("attert", "Attert"),
            ("aubange", "Aubange"),
            ("aubel", "Aubel"),
            ("awans", "Awans"),
            ("aywaille", "Aywaille"),
            ("aaelen", "Baelen"),
            ("bassenge", "Bassenge"),
            ("bastogne", "Bastogne"),
            ("beaumont", "Beaumont"),
            ("beauraing", "Beauraing"),
            ("beauvechain", "Beauvechain"),
            ("beloeil", "Belœil"),
            ("berloz", "Berloz"),
            ("bernissart", "Bernissart"),
            ("bertogne", "Bertogne"),
            ("bertrix", "Bertrix"),
            ("beyneheusay", "Beyne-Heusay"),
            ("bievre", "Bièvre"),
            ("binche", "Binche"),
            ("blegny", "Blegny"),
            ("bouillon", "Bouillon"),
            ("boussu", "Boussu"),
            ("brainelalleud", "Braine-l'Alleud"),
            ("brainelechateau", "Braine-le-Château"),
            ("brainelecomte", "Braine-le-Comte"),
            ("braives", "Braives"),
            ("brugelette", "Brugelette"),
            ("brunehaut", "Brunehaut"),
            ("bullange", "Bullange"),
            ("burdinne", "Burdinne"),
            ("burg-Reuland", "Burg-Reuland"),
            ("butgenbach", "Butgenbach"),
            ("celles", "Celles"),
            ("cerfontaine", "Cerfontaine"),
            ("chapellelezherlaimont", "Chapelle-lez-Herlaimont"),
            ("charleroi", "Charleroi"),
            ("chastre", "Chastre"),
            ("chatelet", "Châtelet"),
            ("chaudfontaine", "Chaudfontaine"),
            ("chaumontgistoux", "Chaumont-Gistoux"),
            ("chievres", "Chièvres"),
            ("chimay", "Chimay"),
            ("chiny", "Chiny"),
            ("ciney", "Ciney"),
            ("clavier", "Clavier"),
            ("colfontaine", "Colfontaine"),
            ("comblainaupont", "Comblain-au-Pont"),
            ("comineswarneton", "Comines-Warneton"),
            ("courcelles", "Courcelles"),
            ("courtsaintetienne", "Court-Saint-Étienne"),
            ("couvin", "Couvin"),
            ("crisnee", "Crisnée"),
            ("dalhem", "Dalhem"),
            ("daverdisse", "Daverdisse"),
            ("dinant", "Dinant"),
            ("dison", "Dison"),
            ("doische", "Doische"),
            ("donceel", "Donceel"),
            ("dour", "Dour"),
            ("durbuy", "Durbuy"),
            ("ecaussinnes", "Écaussinnes"),
            ("eghezee", "Éghezée"),
            ("ellezelles", "Ellezelles"),
            ("enghien", "Enghien"),
            ("engis", "Engis"),
            ("erezee", "Érezée"),
            ("erquelinnes", "Erquelinnes"),
            ("esneux", "Esneux"),
            ("estaimpuis", "Estaimpuis"),
            ("estinnes", "Estinnes"),
            ("etalle", "Étalle"),
            ("eupen", "Eupen"),
            ("faimes", "Faimes"),
            ("farciennes", "Farciennes"),
            ("fauvillers", "Fauvillers"),
            ("fernelmont", "Fernelmont"),
            ("ferrieres", "Ferrières"),
            ("fexhelehautclocher", "Fexhe-le-Haut-Clocher"),
            ("flemalle", "Flémalle"),
            ("fleron", "Fléron"),
            ("fleurus", "Fleurus"),
            ("flobecq", "Flobecq"),
            ("floreffe", "Floreffe"),
            ("florennes", "Florennes"),
            ("florenville", "Florenville"),
            ("fontaineleveque", "Fontaine-l'Évêque"),
            ("fosseslaville", "Fosses-la-Ville"),
            ("frameries", "Frameries"),
            ("frasneslezanvaing", "Frasnes-lez-Anvaing"),
            ("froidchapelle", "Froidchapelle"),
            ("gedinne", "Gedinne"),
            ("geer", "Geer"),
            ("gembloux", "Gembloux"),
            ("genappe", "Genappe"),
            ("gerpinnes", "Gerpinnes"),
            ("gesves", "Gesves"),
            ("gouvy", "Gouvy"),
            ("gracehollogne", "Grâce-Hollogne"),
            ("grezdoiceau", "Grez-Doiceau"),
            ("habay", "Habay"),
            ("hamsurheurenalinnes", "Ham-sur-Heure-Nalinnes"),
            ("hamoir", "Hamoir"),
            ("hamois", "Hamois"),
            ("hannut", "Hannut"),
            ("hastiere", "Hastière"),
            ("havelange", "Havelange"),
            ("helecine", "Hélécine"),
            ("hensies", "Hensies"),
            ("herbeumont", "Herbeumont"),
            ("heron", "Héron"),
            ("herstal", "Herstal"),
            ("herve", "Herve"),
            ("honnelles", "Honnelles"),
            ("hotton", "Hotton"),
            ("houffalize", "Houffalize"),
            ("houyet", "Houyet"),
            ("huy", "Huy"),
            ("incourt", "Incourt"),
            ("ittre", "Ittre"),
            ("jalhay", "Jalhay"),
            ("jemeppesursambre", "Jemeppe-sur-Sambre"),
            ("jodoigne", "Jodoigne"),
            ("juprelle", "Juprelle"),
            ("jurbise", "Jurbise"),
            ("labruyere", "La Bruyère"),
            ("lacalamine", "La Calamine"),
            ("lahulpe", "La Hulpe"),
            ("larocheenardenne", "La Roche-en-Ardenne"),
            ("lasne", "Lasne"),
            ("leglise", "Léglise"),
            ("lens", "Lens"),
            ("leroeulx", "Le Rœulx"),
            ("lesbonsvillers", "Les Bons Villers"),
            ("lessines", "Lessines"),
            ("leuzeenhainaut", "Leuze-en-Hainaut"),
            ("libin", "Libin"),
            ("libramontchevigny", "Libramont-Chevigny"),
            ("liege", "Liège"),
            ("lierneux", "Lierneux"),
            ("limbourg", "Limbourg"),
            ("lincent", "Lincent"),
            ("lobbes", "Lobbes"),
            ("lontzen", "Lontzen"),
            ("lalouviere", "La Louvière"),
            ("malmedy", "Malmedy"),
            ("manage", "Manage"),
            ("manhay", "Manhay"),
            ("marcheenfamenne", "Marche-en-Famenne"),
            ("marchin", "Marchin"),
            ("martelange", "Martelange"),
            ("meixdevantvirton", "Meix-devant-Virton"),
            ("merbeslechateau", "Merbes-le-Château"),
            ("messancy", "Messancy"),
            ("mettet", "Mettet"),
            ("modave", "Modave"),
            ("momignies", "Momignies"),
            ("mons", "Mons"),
            ("montdelenclus", "Mont-de-l'Enclus"),
            ("montignyletilleul", "Montigny-le-Tilleul"),
            ("montsaintguibert", "Mont-Saint-Guibert"),
            ("morlanwelz", "Morlanwelz"),
            ("mouscron", "Mouscron"),
            ("musson", "Musson"),
            ("namur", "Namur"),
            ("nandrin", "Nandrin"),
            ("nassogne", "Nassogne"),
            ("neufchateau", "Neufchâteau"),
            ("neupre", "Neupré"),
            ("nivelles", "Nivelles"),
            ("ohey", "Ohey"),
            ("olne", "Olne"),
            ("onhaye", "Onhaye"),
            ("oreye", "Oreye"),
            ("orpjauche", "Orp-Jauche"),
            ("ottignieslouvainlaneuve", "Ottignies-Louvain-la-Neuve"),
            ("ouffet", "Ouffet"),
            ("oupeye", "Oupeye"),
            ("paliseul", "Paliseul"),
            ("pecq", "Pecq"),
            ("pepinster", "Pepinster"),
            ("peruwelz", "Péruwelz"),
            ("perwez", "Perwez"),
            ("philippeville", "Philippeville"),
            ("plombieres", "Plombières"),
            ("pontacelles", "Pont-à-Celles"),
            ("profondeville", "Profondeville"),
            ("quaregnon", "Quaregnon"),
            ("quevy", "Quévy"),
            ("quievrain", "Quiévrain"),
            ("raeren", "Raeren"),
            ("ramillies", "Ramillies"),
            ("rebecq", "Rebecq"),
            ("remicourt", "Remicourt"),
            ("rendeux", "Rendeux"),
            ("rixensart", "Rixensart"),
            ("rochefort", "Rochefort"),
            ("rouvroy", "Rouvroy"),
            ("rumes", "Rumes"),
            ("sainteode", "Sainte-Ode"),
            ("saintgeorgessurmeuse", "Saint-Georges-sur-Meuse"),
            ("saintghislain", "Saint-Ghislain"),
            ("sainthubert", "Saint-Hubert"),
            ("saintléger", "Saint-Léger"),
            ("saintnicolas", "Saint-Nicolas"),
            ("saintvith", "Saint-Vith"),
            ("sambreville", "Sambreville"),
            ("seneffe", "Seneffe"),
            ("seraing", "Seraing"),
            ("silly", "Silly"),
            ("sivryrance", "Sivry-Rance"),
            ("soignies", "Soignies"),
            ("sombreffe", "Sombreffe"),
            ("sommeleuze", "Somme-Leuze"),
            ("soumagne", "Soumagne"),
            ("spa", "Spa"),
            ("sprimont", "Sprimont"),
            ("stavelot", "Stavelot"),
            ("stoumont", "Stoumont"),
            ("tellin", "Tellin"),
            ("tenneville", "Tenneville"),
            ("theux", "Theux"),
            ("thimisterclermont", "Thimister-Clermont"),
            ("thuin", "Thuin"),
            ("tinlot", "Tinlot"),
            ("tintigny", "Tintigny"),
            ("tournai", "Tournai"),
            ("troisponts", "Trois-Ponts"),
            ("trooz", "Trooz"),
            ("tubize", "Tubize"),
            ("vauxsursure", "Vaux-sur-Sûre"),
            ("verlaine", "Verlaine"),
            ("verviers", "Verviers"),
            ("vielsalm", "Vielsalm"),
            ("villerslebouillet", "Villers-le-Bouillet"),
            ("villerslaville", "Villers-la-Ville"),
            ("viroinval", "Viroinval"),
            ("virton", "Virton"),
            ("vise", "Visé"),
            ("vressesursemois", "Vresse-sur-Semois"),
            ("waimes", "Waimes"),
            ("walcourt", "Walcourt"),
            ("walhain", "Walhain"),
            ("wanze", "Wanze"),
            ("waremme", "Waremme"),
            ("wasseiges", "Wasseiges"),
            ("waterloo", "Waterloo"),
            ("wavre", "Wavre"),
            ("welkenraedt", "Welkenraedt"),
            ("wellin", "Wellin"),
            ("yvoir", "Yvoir"),
        ]
        terms = [
            SimpleTerm(value=pair[0], token=pair[0], title=pair[1])
            for pair in municipal_entities
        ]
        return SimpleVocabulary(terms)


municipalentitiesvocabulary = MunicipalEntitiesVocabularyFactory()



# -*- coding: utf-8 -*-

from collective.taxonomy.interfaces import ITaxonomy
from collective.z3cform.select2.widget.widget import MultiSelect2FieldWidget
from datetime import datetime
from library.core.widget.textdate import TextDateFieldWidget
from library.core.widget.title import TextTitleFieldWidget
from plone.app.textfield import RichText
from plone.app.textfield.value import IRichTextValue
from plone.app.vocabularies.catalog import CatalogSource
from plone.autoform import directives as form
from plone.dexterity.browser import view
from plone.dexterity.content import Container
from plone.dexterity.utils import iterSchemata
from plone.indexer.decorator import indexer
from plone.namedfile import field as namedfile
from plone.supermodel import model
from plone.supermodel.directives import fieldset
from Products.CMFPlone.utils import getToolByName
from Products.CMFPlone.utils import safe_unicode
from re import match
from z3c.form.browser.radio import RadioFieldWidget
from z3c.form.validator import SimpleFieldValidator
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from zope import schema
from zope.component import queryUtility
from zope.interface import implementer
from zope.interface import Invalid
from zope.schema import getFields
from zope.schema import ValidationError

import six


def fileSize(value):
    if value.size > 30000000:
        raise InvalidFileSizeError(value)
    return True


class InvalidFileSizeError(ValidationError):
    """Exception for file size too large"""

    __doc__ = "Le fichier doit faire moins de 30MB."


class IPatrimoine(model.Schema):
    """Marker interface for Patrimoine"""

    # model.load("patrimoine.xml")

    numero_inventaire = schema.TextLine(title=(u"Numéro d'inventaire"), required=False)
    informations = RichText(title=(u"Informations"), required=False)

    contenus_lies = RelationList(
        title=u"Contenus liés",
        default=[],
        value_type=RelationChoice(
            title=(u"Relation Choice"),
            source=CatalogSource(portal_type=("Folder", "patrimoine")),
        ),
        required=False,
    )

    fichier_pdf = namedfile.NamedBlobFile(
        title=(u"Fichier PDF"), required=False, constraint=fileSize
    )

    fieldset(
        "Publication",
        fields=[
            "auteur",
            "lieu",
            "editeur",
            "date",
            "nombre_de_pages",
            "format_1",
            "illustre",
        ],
    )
    auteur = schema.TextLine(title=(u"Auteur"), required=False)
    lieu = schema.TextLine(title=(u"Lieu"), required=False)
    editeur = schema.TextLine(title=(u"Éditeur"), required=False)

    form.widget("date", TextDateFieldWidget)
    date = schema.TextLine(title=(u"Date"), required=False)

    nombre_de_pages = schema.TextLine(title=(u"Nombre de pages"), required=False)
    format_1 = schema.TextLine(title=(u"Format"), required=False)

    illustre = schema.Bool(title=(u"Illustré"), required=False)
    # form.widget(illustre=RadioFieldWidget)

    fieldset(
        "Carte postale",
        fields=["nom_de_rue", "couleur"],
    )
    nom_de_rue = schema.TextLine(title=(u"Nom de rue"), required=False)
    couleur = schema.Choice(
        title=(u"Couleur"),
        required=False,
        vocabulary="library.core.vocabularies.colors_vocabulary",
    )

    fieldset(
        "Registre",
        fields=[
            "nom_prenom_1",
            "nom_du_conjoint_1",
            "evenement_date_1",
            "date_evenement_1",
            "nom_prenom_2",
            "nom_du_conjoint_2",
            "evenement_date_2",
            "date_evenement_2",
            "nom_prenom_3",
            "nom_du_conjoint_3",
            "evenement_date_3",
            "date_evenement_3",
            "nom_prenom_4",
            "nom_du_conjoint_4",
            "evenement_date_4",
            "date_evenement_4",
        ],
    )

    nom_prenom_1 = schema.TextLine(title=(u"Nom prénom 1"), required=False)
    nom_du_conjoint_1 = schema.TextLine(title=(u"Nom du conjoint 1"), required=False)
    evenement_date_1 = schema.Choice(
        title=(u"Evénement lié à la date 1"),
        required=False,
        vocabulary="library.core.vocabularies.eventsdate_vocabulary",
    )
    date_evenement_1 = schema.TextLine(
        title=(u"Date événement 1"), description="(jj/mm/aaaa)", required=False
    )

    nom_prenom_2 = schema.TextLine(title=(u"Nom prénom 2"), required=False)
    nom_du_conjoint_2 = schema.TextLine(title=(u"Nom du conjoint 2"), required=False)
    evenement_date_2 = schema.Choice(
        title=(u"Evénement lié à la date 2"),
        required=False,
        vocabulary="library.core.vocabularies.eventsdate_vocabulary",
    )
    date_evenement_2 = schema.TextLine(
        title=(u"Date événement 2"), description="(jj/mm/aaaa)", required=False
    )

    nom_prenom_3 = schema.TextLine(title=(u"Nom prénom 3"), required=False)
    nom_du_conjoint_3 = schema.TextLine(title=(u"Nom du conjoint 3"), required=False)
    evenement_date_3 = schema.Choice(
        title=(u"Evénement lié à la date 3"),
        required=False,
        vocabulary="library.core.vocabularies.eventsdate_vocabulary",
    )
    date_evenement_3 = schema.TextLine(
        title=(u"Date événement 3"), description="(jj/mm/aaaa)", required=False
    )

    nom_prenom_4 = schema.TextLine(title=(u"Nom prénom 4"), required=False)
    nom_du_conjoint_4 = schema.TextLine(title=(u"Nom du conjoint 4"), required=False)
    evenement_date_4 = schema.Choice(
        title=(u"Evénement lié à la date 4"),
        required=False,
        vocabulary="library.core.vocabularies.eventsdate_vocabulary",
    )
    date_evenement_4 = schema.TextLine(
        title=(u"Date événement 4"), description="(jj/mm/aaaa)", required=False
    )

    fieldset("Média", fields=["auteur_du_media", "duree", "couleur_du_media"])

    auteur_du_media = schema.TextLine(title=(u"Auteur du média"), required=False)
    duree = schema.TextLine(title=(u"Durée"), required=False)
    couleur_du_media = schema.Choice(
        title=(u"Couleur du média"),
        required=False,
        vocabulary="library.core.vocabularies.colors_vocabulary",
    )

    fieldset(
        "Bien et PPPW",
        fields=[
            "group_identification",
            "nature_du_bien",
            "lieu_dit",
            "appellation_courante",
            "primary_category",
            "secondary_category",
            "autre",
            "group_localisation",
            "provinces",
            "municipal_entity",
            "group_owner",
            "owner_datas",
            "owner_name",
            "owner_address",
            "owner_zip_code",
            "owner_entity",
            "owner_email",
            "owner_phone",
            "group_item_status",
            "item_status",
            "group_item_description",
            "descriptif",
            "dimensions",
            "materiaux",
            "inscription_datation",
            "urban_context",
            "public_visibility",
            "direct_reachability",
            "group_item_conservation",
            "item_state",
            "noted_degradation",
            "reallocation_project",
            "group_item_history",
            "fonction_passee_et_actuelle",
            "group_item_notes_and_comments",
            "remarques_commentaires",
        ],
    )
    # 1. Identification de l'élément
    form.widget("group_identification", TextTitleFieldWidget)
    group_identification = schema.TextLine(
        title=(u"Identification de l’élément"), required=False
    )
    nature_du_bien = schema.TextLine(title=(u"Nature du bien"), required=False)
    lieu_dit = schema.TextLine(title=(u"Lieu dit"), required=False)
    appellation_courante = schema.TextLine(
        title=(u"Appellation courante"), required=False
    )
    form.widget("primary_category", TextTitleFieldWidget)
    primary_category = schema.TextLine(
        title=(u"Catégorie principale"),
        description=(
            u'La catégorie principale est renseignée sous l\'onglet "Catégorisation"'
        ),
        required=False,
    )
    form.widget("secondary_category", TextTitleFieldWidget)
    secondary_category = schema.TextLine(
        title=(u"Catégorie secondaire"),
        description=(
            u'La catégorie secondaire est renseignée sous l\'onglet "Catégorisation"'
        ),
        required=False,
    )
    autre = schema.Text(title=(u"Autre..."), required=False)
    # 2. Localisation de l'élément
    form.widget("group_localisation", TextTitleFieldWidget)
    group_localisation = schema.TextLine(
        title=(u"Localisation de l’élément"), required=False
    )

    provinces = schema.Choice(
        title=("Province"),
        required=False,
        vocabulary="library.core.vocabularies.provinces_vocabulary",
        default=None,
    )
    municipal_entity = schema.Choice(
        title=(u"Entité"),
        required=False,
        vocabulary="library.core.vocabularies.municipalentities_vocabulary",
        default=None,
    )

    # 3. Données relatives au propriétaire
    form.widget("group_owner", TextTitleFieldWidget)
    group_owner = schema.TextLine(
        title=(u"Données relatives au propriétaire"), required=False
    )

    form.read_permission(owner_datas="cmf.ModifyPortalContent")
    form.widget("owner_datas", RadioFieldWidget)
    owner_datas = schema.Choice(
        title=(u"Type de propriété"),
        required=False,
        values=["Privé", "Publique", "Statut inconnu"],
        default=None,
    )

    form.read_permission(owner_name="cmf.ModifyPortalContent")
    owner_name = schema.TextLine(
        title=(u"Nom-Prénom / Nom de l’organisme"), required=False
    )

    form.read_permission(owner_address="cmf.ModifyPortalContent")
    owner_address = schema.TextLine(title=(u"Adresse"), required=False)

    form.read_permission(owner_zip_code="cmf.ModifyPortalContent")
    owner_zip_code = schema.TextLine(title=(u"Code postal"), required=False)

    form.read_permission(owner_entity="cmf.ModifyPortalContent")
    owner_entity = schema.TextLine(title=(u"Entité/Commune"), required=False)

    form.read_permission(owner_email="cmf.ModifyPortalContent")
    owner_email = schema.TextLine(title=(u"Adresse e-mail"), required=False)

    form.read_permission(owner_phone="cmf.ModifyPortalContent")
    owner_phone = schema.TextLine(title=(u"Téléphone / Gsm"), required=False)

    # 4. Statut de l’élément
    form.widget("group_item_status", TextTitleFieldWidget)
    group_item_status = schema.TextLine(title=(u"Statut de l’élément"), required=False)

    form.widget(item_status=MultiSelect2FieldWidget)
    item_status = schema.List(
        title=(u"Statuts"),
        value_type=schema.Choice(
            title=(u"District(s) concerned"),
            values=[
                u"Monument",
                u"Site",
                u"Ensemble architectural",
                u"Zone de protection",
                safe_unicode(u"IPIC (repris à l'inventaire régional)"),
            ],
        ),
        required=False,
    )

    # 5. Description de l’élément

    form.widget("group_item_description", TextTitleFieldWidget)
    group_item_description = schema.TextLine(
        title=(u"Description de l’élément"), required=False
    )
    descriptif = schema.Text(title=(u"Descriptif"), required=False)
    dimensions = schema.TextLine(title=(u"Dimensions"), required=False)
    materiaux = schema.TextLine(title=(u"Matériaux"), required=False)
    inscription_datation = schema.Text(
        title=(u"Inscription(s) - Datation"), required=False
    )
    urban_context = schema.Text(
        title=(u"Contexte urbanistique et abords"), required=False
    )
    form.widget("public_visibility", RadioFieldWidget)
    public_visibility = schema.Bool(
        title=(u"Visibilité depuis le domaine public"), required=False
    )
    form.widget("direct_reachability", RadioFieldWidget)
    direct_reachability = schema.Bool(title=(u"Accessibilité directe"), required=False)

    # 6. Etat de conservation de l’élément

    form.widget("group_item_conservation", TextTitleFieldWidget)
    group_item_conservation = schema.TextLine(
        title=(u"Etat de conservation de l’élément"), required=False
    )

    # quid id=etat.
    form.widget("owner_datas", RadioFieldWidget)
    item_state = schema.Choice(
        title=(u"Etat général de l’élément"),
        required=False,
        values=["Bon", "Moyen", "Mauvais"],
        default=None,
    )
    noted_degradation = schema.Text(title=(u"Dégradation constatée"), required=False)
    form.widget("reallocation_project", RadioFieldWidget)
    reallocation_project = schema.Bool(
        title=(u"Projet de conservation/ Réaffectation en cours"), required=False
    )

    # 7. Historique/Anecdotes
    form.widget("group_item_history", TextTitleFieldWidget)
    group_item_history = schema.TextLine(
        title=(u"Historique/Anecdotes"), required=False
    )
    fonction_passee_et_actuelle = schema.Text(
        title=(u"Fonction(s) passée(s) et actuelle(s)"), required=False
    )

    # 8. Remarques
    form.widget("group_item_notes_and_comments", TextTitleFieldWidget)
    group_item_notes_and_comments = schema.TextLine(
        title=(u"Remarques"), required=False
    )
    remarques_commentaires = schema.Text(
        title=(u"Remarques et commentaires"), required=False
    )


class DateValidator(SimpleFieldValidator):

    regex_formats = {
        "\d{8}$": "%d%m%Y",
        "\d{6}$": "%m%Y",
        "\d{4}$": "%Y",
        "\d{1,2}/\d{1,2}/\d{4}$": "%d/%m/%Y",
        "\d{1,2}/\d{4}$": "%m/%Y",
        "\d{1,2}-\d{1,2}-\d{4}$": "%d-%m-%Y",
        "\d{1,2}-\d{4}$": "%m-%Y",
    }

    def validate(self, value, force=False):
        super(DateValidator, self).validate(value, force)
        if value:
            stripped = value.strip()
            for regex, datetime_format in self.regex_formats.items():
                if match(regex, stripped):
                    try:
                        datetime.strptime(stripped, datetime_format).date()
                        return True
                    except ValueError:
                        raise Invalid(u"Date invalide")
            raise Invalid(
                u"Format d'encodage non reconnu (jour/mois/année, mois/année ou année)"
            )


@implementer(IPatrimoine)
class Patrimoine(Container):
    """ """


class PatrimoineView(view.DefaultView):
    """ """

    def is_TextTitleWidget(self, current_widget):
        from library.core.widget.title import TextTitleWidget

        return isinstance(current_widget, TextTitleWidget)

    def is_there_any_fields_after_this_title(self, current_widget, lst_widgets):
        current_index = lst_widgets.index(current_widget)
        if (current_index + 1) < len(lst_widgets) and len(
            lst_widgets[current_index + 1].value
        ) > 0:
            return True
        else:
            return False

    def is_there_any_values(self, lst_widgets):
        if lst_widgets:
            return (
                False
                if set(
                    [
                        widget.value
                        if not isinstance(widget.value, list)
                        else widget.value[0]
                        if widget.value != [] and widget.value[0] != "unselected"
                        else ""
                        for widget in lst_widgets
                    ]
                )
                == {""}
                else True
            )
        else:
            return False

    def is_geolocated(self):
        return is_geolocated(self.context)


@indexer(IPatrimoine)
def searchabletext_patrimoine(object, **kw):
    """
    Indexes the following field types in Patrimoine objects,
    making them available in Full Text Search:
    - text
    - rich text
    - keywords
    - taxonomies
    """
    result = []
    subjects = getattr(object, "subject", None)
    if type(subjects) is tuple:
        text = " ".join([s for s in subjects if isinstance(s, six.text_type)])
        result.append(text)

    for schemata in iterSchemata(object):
        if "collective.taxonomy.generated" in str(schemata):
            value = getattr(object, "taxonomy_{0}".format(schemata.__name__), None)
            if value:
                value = [value] if isinstance(value, six.text_type) else value
                translator = queryUtility(
                    ITaxonomy, name="collective.taxonomy.{0}".format(schemata.__name__)
                )
                for taxonomy_id in value:
                    translation = translator.translate(
                        taxonomy_id, target_language="fr"
                    )
                    text = translation
                    result.append(text)
            continue

        for field_name, field_type in getFields(schemata).items():
            value = getattr(object, field_name, None)
            if isinstance(value, six.text_type):
                text = value
                result.append(text)
            elif IRichTextValue.providedBy(value):
                transforms = getToolByName(object, "portal_transforms")
                text = (
                    transforms.convertTo(
                        "text/plain", value.raw, mimetype=value.mimeType
                    )
                    .getData()
                    .strip()
                )
                result.append(text)

    return " ".join(result)


def is_geolocated(obj):
    if getattr(obj, "geolocation", None) is not None:
        if (
            getattr(obj.geolocation, "latitude", None) is not None
            and getattr(obj.geolocation, "longitude", None) is not None
        ):
            if float(obj.geolocation.latitude) != float(0) and float(
                obj.geolocation.longitude
            ) != float(0):
                return True
            else:
                return False
        else:
            return False
    else:
        return False


@indexer(IPatrimoine)
def is_geolocated_indexer(obj):
    return is_geolocated(obj)



# -*- coding: utf-8 -*-
from library.core.testing import LIBRARY_CORE_INTEGRATION_TESTING
from library.core.utils import add_behavior
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.formwidget.geolocation.geolocation import Geolocation

import unittest


class TestGeolocation(unittest.TestCase):

    layer = LIBRARY_CORE_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.patrimoine = api.content.create(
            container=self.portal, type="patrimoine", title="Patrimoine"
        )

    def test_is_geolocated(self):
        add_behavior(
            "patrimoine", "collective.geolocationbehavior.geolocation.IGeolocatable"
        )
        catalog = api.portal.get_tool("portal_catalog")
        brain = catalog(UID=self.patrimoine.UID())[0]
        self.assertEqual(self.patrimoine.geolocation, None)
        self.patrimoine.geolocation = Geolocation(latitude="55.0", longitude="5.0")
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertTrue(is_geolocated)

    def test_false_if_no_geolocation(self):
        add_behavior(
            "patrimoine", "collective.geolocationbehavior.geolocation.IGeolocatable"
        )
        catalog = api.portal.get_tool("portal_catalog")
        brain = catalog(UID=self.patrimoine.UID())[0]
        self.assertEqual(self.patrimoine.geolocation, None)
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)

    def test_false_if_no_longitude_or_longitude_eq_0(self):
        add_behavior(
            "patrimoine", "collective.geolocationbehavior.geolocation.IGeolocatable"
        )
        catalog = api.portal.get_tool("portal_catalog")
        brain = catalog(UID=self.patrimoine.UID())[0]
        self.assertEqual(self.patrimoine.geolocation, None)
        self.patrimoine.geolocation = Geolocation(latitude="55.0")
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)
        self.patrimoine.geolocation = Geolocation(longitude="0.0", latitude="55.0")
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)

    def test_false_if_no_latitude_or_latiude_eq_0(self):
        add_behavior(
            "patrimoine", "collective.geolocationbehavior.geolocation.IGeolocatable"
        )
        catalog = api.portal.get_tool("portal_catalog")
        brain = catalog(UID=self.patrimoine.UID())[0]
        self.assertEqual(self.patrimoine.geolocation, None)
        self.patrimoine.geolocation = Geolocation(longitude="5.0")
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)
        self.patrimoine.geolocation = Geolocation(longitude="5.0", latitude="0.0")
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)

    def test_false_if_no_latitude_and_no_longitude(self):
        add_behavior(
            "patrimoine", "collective.geolocationbehavior.geolocation.IGeolocatable"
        )
        catalog = api.portal.get_tool("portal_catalog")
        brain = catalog(UID=self.patrimoine.UID())[0]
        self.assertEqual(self.patrimoine.geolocation, None)
        self.patrimoine.geolocation = "Kamoulox"
        # reindex
        catalog.catalog_object(brain.getObject(), idxs=["is_geolocated"])
        is_geolocated = catalog.getIndexDataForRID(brain.getRID())["is_geolocated"]
        self.assertFalse(is_geolocated)



# -*- coding: utf-8 -*-
from ..interfaces import ILibraryCoreLayer
from collective.z3cform.select2.widget.widget import SingleSelect2FieldWidget
from z3c.form import interfaces

import zope.component
import zope.interface
import zope.schema.interfaces


@zope.component.adapter(zope.schema.interfaces.IChoice, ILibraryCoreLayer)
@zope.interface.implementer(interfaces.IFieldWidget)
def ChoiceWidgetDispatcher(field, request):
    """Dispatch widget for IChoice based also on its source."""

    if not field.vocabulary:  # simple taxonomy
        return SingleSelect2FieldWidget(field, request)
    else:
        return zope.component.getMultiAdapter(
            (field, field.vocabulary, request), interfaces.IFieldWidget
        )



# -*- coding: utf-8 -*-
from library.core.content.patrimoine import InvalidFileSizeError
from library.core.content.patrimoine import fileSize
from library.core.testing import LIBRARY_CORE_INTEGRATION_TESTING
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.namedfile.file import NamedBlobFile
from plone.namedfile.field import NamedFile

import unittest


class TestPatrimoine(unittest.TestCase):

    layer = LIBRARY_CORE_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.patrimoine = api.content.create(
            container=self.portal, type="patrimoine", title="Patrimoine"
        )

    def test_filesize(self):
        # original value in patrimoine : 30000000
        file = NamedFile()
        file.data = "0" * 30000000
        self.patrimoine.fichier_pdf = NamedBlobFile(
            data=file.data, filename=u"bigfile.pdf"
        )
        self.assertTrue(fileSize(self.patrimoine.fichier_pdf))
        file = NamedFile()
        file.data = "0" * 30000001
        self.patrimoine.fichier_pdf = NamedBlobFile(
            data=file.data, filename=u"bigfile.pdf"
        )
        with self.assertRaises(InvalidFileSizeError):
            self.assertRaises(
                InvalidFileSizeError, fileSize(self.patrimoine.fichier_pdf)
            )



# -*- coding: utf-8 -*-
from datetime import date
from datetime import datetime
from plone.app.z3cform.interfaces import ITextWidget
from re import match
from z3c.form.browser.text import TextWidget
from z3c.form.converter import BaseDataConverter
from z3c.form.converter import FormatterValidationError
from z3c.form.interfaces import IDataConverter
from z3c.form.interfaces import IFieldWidget
from z3c.form.widget import FieldWidget
from zope.component import adapts
from zope.interface import implementer
from zope.schema.interfaces import ITextLine


class ITextDateWidget(ITextWidget):
    """Marker interface for TextDate"""


@implementer(ITextDateWidget)
class TextDateWidget(TextWidget):
    pass


@implementer(IFieldWidget)
def TextDateFieldWidget(field, request):
    """IFieldWidget factory for TextDateWidget."""
    return FieldWidget(field, TextDateWidget(request))


@implementer(IDataConverter)
class TextDateConverter(BaseDataConverter):
    """Text field, accepting dates only"""

    adapts(ITextLine, ITextDateWidget)

    regex_formats = {
        "\d{8}$": "%d%m%Y",
        "\d{6}$": "%m%Y",
        "\d{4}$": "%Y",
        "\d{1,2}/\d{1,2}/\d{4}$": "%d/%m/%Y",
        "\d{1,2}/\d{4}$": "%m/%Y",
        "\d{1,2}-\d{1,2}-\d{4}$": "%d-%m-%Y",
        "\d{1,2}-\d{4}$": "%m-%Y",
    }

    def toWidgetValue(self, value):
        if value is self.field.missing_value:
            return u""

        if type(value) == date:
            return "{v.day:02d}/{v.month:02d}/{v.year}".format(v=value)
        else:
            return value

    def toFieldValue(self, value):
        if value == u"":
            return self.field.missing_value

        stripped = value.strip()
        for regex, datetime_format in self.regex_formats.items():
            if match(regex, stripped):
                try:
                    datetime.strptime(stripped, datetime_format)
                except ValueError:
                    raise FormatterValidationError(u"Date invalide {0}", value)
                else:
                    return stripped
        raise FormatterValidationError(
            u"Format d'encodage non reconnu (jour/mois/année, mois/année ou année)",
            value,
        )



# -*- coding: utf-8 -*-
from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneSandboxLayer
from plone.testing import z2

import library.core


class LibraryCoreLayer(PloneSandboxLayer):

    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.

        self.loadZCML(name="testing.zcml", package=library.core)

    def setUpPloneSite(self, portal):
        applyProfile(portal, "library.core:default")


LIBRARY_CORE_FIXTURE = LibraryCoreLayer()


LIBRARY_CORE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(LIBRARY_CORE_FIXTURE,), name="LibraryCoreLayer:IntegrationTesting"
)


LIBRARY_CORE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(LIBRARY_CORE_FIXTURE,), name="LibraryCoreLayer:FunctionalTesting"
)


LIBRARY_CORE_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(LIBRARY_CORE_FIXTURE, REMOTE_LIBRARY_BUNDLE_FIXTURE, z2.ZSERVER_FIXTURE),
    name="LibraryCoreLayer:AcceptanceTesting",
)



# -*- coding: utf-8 -*-

import os
import pkg_resources
import subprocess


domain = "library.core"
os.chdir(pkg_resources.resource_filename(domain, ""))
os.chdir("../../../")
target_path = "src/library/core/"
locale_path = target_path + "locales/"
i18ndude = "./bin/i18ndude"


def locale_folder_setup():
    os.chdir(locale_path)
    languages = [d for d in os.listdir(".") if os.path.isdir(d)]
    for lang in languages:
        folder = os.listdir(lang)
        if "LC_MESSAGES" in folder:
            continue
        else:
            lc_messages_path = lang + "/LC_MESSAGES/"
            os.mkdir(lc_messages_path)
            cmd = "msginit --locale={0} --input={1}.pot --output={2}/LC_MESSAGES/{3}.po".format(  # NOQA: E501
                lang,
                domain,
                lang,
                domain,
            )
            subprocess.call(
                cmd,
                shell=True,
            )

    os.chdir("../../../../")


def _rebuild():
    cmd = "{0} rebuild-pot --pot {1}/{2}.pot --create {3} {4}".format(
        i18ndude,
        locale_path,
        domain,
        domain,
        target_path,
    )
    subprocess.call(
        cmd,
        shell=True,
    )


def _sync():
    cmd = "{0} sync --pot {1}/{2}.pot {3}*/LC_MESSAGES/{4}.po".format(
        i18ndude,
        locale_path,
        domain,
        locale_path,
        domain,
    )
    subprocess.call(
        cmd,
        shell=True,
    )


def update_locale():
    locale_folder_setup()
    _sync()
    _rebuild()



# -*- coding: utf-8 -*-
from plone.app.z3cform.interfaces import ITextWidget
from z3c.form.browser.text import TextWidget
from z3c.form.interfaces import IFieldWidget
from z3c.form.widget import FieldWidget
from zope.interface import implementer


class ITextTitleWidget(ITextWidget):
    """Marker interface for TextDate"""


@implementer(ITextTitleWidget)
class TextTitleWidget(TextWidget):
    def title_renderer(self):
        return True


@implementer(IFieldWidget)
def TextTitleFieldWidget(field, request):
    """IFieldWidget factory for TextDateWidget."""
    return FieldWidget(field, TextTitleWidget(request))



# -*- coding: utf-8 -*-
from plone.app.z3cform.interfaces import ITextWidget
from z3c.form.browser.text import TextWidget
from z3c.form.interfaces import IFieldWidget
from z3c.form.widget import FieldWidget
from zope.interface import implementer


class IHiddenHoneyPotWidget(ITextWidget):
    """Marker interface for TextDate"""


@implementer(IHiddenHoneyPotWidget)
class HiddenHoneyPotWidget(TextWidget):

    style = "display:none"

    def title_renderer(self):
        return False


@implementer(IFieldWidget)
def HiddenHoneyPotFieldWidget(field, request):
    return FieldWidget(field, HiddenHoneyPotWidget(request))



# -*- coding: utf-8 -*-
"""Installer for the library.core package."""

from setuptools import find_packages
from setuptools import setup


long_description = "\n\n".join(
    [
        open("README.rst").read(),
        open("CONTRIBUTORS.rst").read(),
        open("CHANGES.rst").read(),
    ]
)


setup(
    name="library.core",
    version="2.0.14",
    description="Core package for Bibliotheca",
    long_description=long_description,
    # Get more from https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 5.2",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="Python Plone",
    author="Nicolas Demonte",
    author_email="support@imio.be",
    url="https://pypi.python.org/pypi/library.core",
    license="GPL version 2",
    packages=find_packages("src", exclude=["ez_setup"]),
    namespace_packages=["library"],
    package_dir={"": "src"},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        # -*- Extra requirements: -*-
        "plone.api>=1.8.4",
        "Products.GenericSetup>=1.8.2",
        "setuptools",
        "z3c.jbot",
        "plone.app.discussion",
        "collective.behavior.gallery",
        "collective.taxonomy",
        "collective.z3cform.select2",
        "collective.faceted.map",
    ],
    extras_require={
        "test": [
            "plone.app.testing",
            # Plone KGS does not use this version, because it would break
            # Remove if your package shall be part of coredev.
            # plone_coredev tests as of 2016-04-01.
            "plone.testing>=5.0.0",
            "plone.app.contenttypes",
            "plone.app.robotframework[debug]",
        ]
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    [console_scripts]
    update_locale = library.core.locales.update:update_locale
    """,
)



# -*- coding: utf-8 -*-

from AccessControl import getSecurityManager
from AccessControl import Unauthorized
from Acquisition import aq_inner
from library.core.widget.hidden_honeypot import HiddenHoneyPotFieldWidget
from plone.app.discussion import _
from plone.app.discussion.browser.comments import CommentForm
from plone.app.discussion.browser.comments import CommentsViewlet as baseCommentsViewlet
from plone.app.discussion.browser.validator import CaptchaValidator
from plone.app.discussion.interfaces import ICaptcha
from plone.app.discussion.interfaces import IComment
from plone.app.discussion.interfaces import IConversation
from plone.app.discussion.interfaces import IDiscussionSettings
from plone.app.discussion.interfaces import IReplies
from plone.autoform import directives
from plone.registry.interfaces import IRegistry
from Products.CMFCore.utils import getToolByName
from Products.statusmessages.interfaces import IStatusMessage
from z3c.form import button
from z3c.form import field
from zope.component import queryUtility
from zope import schema


class ICommentWithHoneyPot(IComment):

    honeypot = schema.TextLine(title=(u"Signature"), required=False)


class CommentFormWithHoneyPot(CommentForm):

    fields = field.Fields(ICommentWithHoneyPot).omit(
        "portal_type",
        "__parent__",
        "__name__",
        "comment_id",
        "mime_type",
        "creator",
        "creation_date",
        "modification_date",
        "author_username",
        "title",
    )

    def updateFields(self):
        super(CommentFormWithHoneyPot, self).updateFields()
        self.fields["honeypot"].widgetFactory = HiddenHoneyPotFieldWidget

    def updateWidgets(self):
        super(CommentFormWithHoneyPot, self).updateWidgets()
        self.widgets["honeypot"].label = u""

    @button.buttonAndHandler(_(u"Cancel"))
    def handleCancel(self, action):
        # This method should never be called, it's only there to show
        # a cancel button that is handled by a jQuery method.
        pass  # pragma: no cover

    @button.buttonAndHandler(
        _(u"add_comment_button", default=u"Comment"), name="comment"
    )
    def handleComment(self, action):
        if self.request.form["form.widgets.honeypot"]:
            return
        context = aq_inner(self.context)

        # Check if conversation is enabled on this content object
        if not self.__parent__.restrictedTraverse(
            "@@conversation_view",
        ).enabled():
            raise Unauthorized(
                "Discussion is not enabled for this content object.",
            )

        # Validation form
        data, errors = self.extractData()
        if errors:
            return

        # Validate Captcha
        registry = queryUtility(IRegistry)
        settings = registry.forInterface(IDiscussionSettings, check=False)
        portal_membership = getToolByName(self.context, "portal_membership")
        captcha_enabled = settings.captcha != "disabled"
        anonymous_comments = settings.anonymous_comments
        anon = portal_membership.isAnonymousUser()
        if captcha_enabled and anonymous_comments and anon:
            if "captcha" not in data:
                data["captcha"] = u""
            captcha = CaptchaValidator(
                self.context, self.request, None, ICaptcha["captcha"], None
            )
            captcha.validate(data["captcha"])

        # Create comment
        comment = self.create_comment(data)

        # Add comment to conversation
        conversation = IConversation(self.__parent__)
        if data["in_reply_to"]:
            # Add a reply to an existing comment
            conversation_to_reply_to = conversation.get(data["in_reply_to"])
            replies = IReplies(conversation_to_reply_to)
            comment_id = replies.addComment(comment)
        else:
            # Add a comment to the conversation
            comment_id = conversation.addComment(comment)

        # Redirect after form submit:
        # If a user posts a comment and moderation is enabled, a message is
        # shown to the user that his/her comment awaits moderation. If the user
        # has 'review comments' permission, he/she is redirected directly
        # to the comment.
        can_review = getSecurityManager().checkPermission("Review comments", context)
        workflowTool = getToolByName(context, "portal_workflow")
        comment_review_state = workflowTool.getInfoFor(
            comment,
            "review_state",
            None,
        )
        if comment_review_state == "pending" and not can_review:
            # Show info message when comment moderation is enabled
            IStatusMessage(self.context.REQUEST).addStatusMessage(
                _("Your comment awaits moderator approval."), type="info"
            )
            self.request.response.redirect(self.action)
        else:
            # Redirect to comment (inside a content object page)
            self.request.response.redirect(self.action + "#" + str(comment_id))


class CommentsViewlet(baseCommentsViewlet):
    form = CommentFormWithHoneyPot



# -*- coding: utf-8 -*-
from plone.dexterity.interfaces import IDexterityFTI
from zope.component import getUtility


def has_behavior(type_name, behavior_name):
    """Check if a behavior is on portal_type"""
    fti = getUtility(IDexterityFTI, name=type_name)
    if not fti:
        return
    behaviors = list(fti.behaviors)
    if behavior_name not in behaviors:
        return False
    else:
        return True


def add_behavior(type_name, behavior_name):
    """Add a behavior to a type"""
    fti = getUtility(IDexterityFTI, name=type_name)
    if not fti:
        return
    behaviors = list(fti.behaviors)
    if behavior_name not in behaviors:
        behaviors.append(behavior_name)
        fti._updateProperty("behaviors", tuple(behaviors))


def remove_behavior(type_name, behavior_name):
    """Add a behavior to a type"""
    fti = getUtility(IDexterityFTI, name=type_name)
    if not fti:
        return
    behaviors = list(fti.behaviors)
    if behavior_name in behaviors:
        behaviors.remove(behavior_name)
        fti._updateProperty("behaviors", tuple(behaviors))
